package RDF::Store;

$VERSION='0.1';

1;

__END__

=head1 NAME

RDF::Store - This is a set of Perl modules that together with its companions XML::Parser::PenRDF(3) and Data::MagicTie(3) allow a user to fetch, parse, process, store and query RDF models.

=head1 SYNOPSIS

	use RDF
        use RDF::Store::NodeFactory;

=head1 DESCRIPTION

This suite of Perl modules has been designed starting from the great work of Sergey Melnik for the Java RDF API - see http://www-db.stanford.edu/~melnik/rdf/api.html

...bal bla bla.....


Modules like RDF::RDFNode, RDF::Literal, RDF::Model and so on define a set of "O-O interfaces" to be implemented by concrete counterparts such as RDF::Store::RDFNode, RDF::Store::Model and others. The modules defined by RDFStore correspond to the Java org.w3c.rdf.model, org.w3c.rdf.util, org.w3c.rdf.implementation.model, org.w3c.tools.crypt, edu.stanford.db.rdf.schema, edu.stanford.db.rdf.vocabulary, org.w3c.rdf.vocabulary.rdf_syntax_19990222, org.w3c.rdf.vocabulary.rdf_schema_19990303, org.w3c.rdf.vocabulary.dublin_core_1999070 packages defined by Sergey Melnik; the Perl code has been structured as follow:


	Perl packages 		   Java classes
--------------------------------------------------------------
RDF::*				org.w3c.rdf.model
--------------------------------------------------------------
RDF::Model			org.w3c.rdf.model.Model
RDF::Literal 			org.w3c.rdf.model.Literal
RDF::RDFNode 			org.w3c.rdf.model.RDFNode
RDF::Resource 			org.w3c.rdf.model.Resource
RDF::Statement 			org.w3c.rdf.model.Statement
RDF::NodeFactory 		org.w3c.rdf.model.NodeFactory
RDF::VirtualModel		org.w3c.rdf.model.VirtualModel
RDF::SetModel 			org.w3c.rdf.model.SetModel


RDF::Digest::*				org.w3c.rdf.util,org.w3c.tools.crypt
----------------------------------------------------------------------------
RDF::Digest				org.w3c.rdf.tools.crypt.Digest
RDF::Digest::Util			org.w3c.rdf.util.DigestUtil
RDF::Digest::AbstractDigest	org.w3c.rdf.util.DigestUtil
RDF::Digest::GenericDigest	org.w3c.rdf.util.DigestUtil
RDF::Digest::MD5			org.w3c.rdf.util.DigestUtil
RDF::Digest::SHA1			org.w3c.rdf.util.DigestUtil


RDF::Store::*				org.w3c.rdf.implementation.model,edu.stanford.db.rdf.schema
---------------------------------------------------------------------------------------------------
RDF::Store::Model			org.w3c.rdf.implementation.model.Model
RDF::Store::Literal			org.w3c.rdf.implementation.model.Literal
RDF::Store::RDFNode			org.w3c.rdf.implementation.model.RDFNode
RDF::Store::Resource		org.w3c.rdf.implementation.model.Resource
RDF::Store::Statement		org.w3c.rdf.implementation.model.Statement
RDF::Store::NodeFactory		org.w3c.rdf.implementation.model.NodeFactory
RDF::Store::VirtualModel		org.w3c.rdf.implementation.model.VirtualModel
RDF::Store::SetModel		org.w3c.rdf.implementation.model.SetModel
RDF::Store::SchemaModel		edu.stanford.db.rdf.schema.RDFSchemaModel

RDF::Vocabulary::*				edu.stanford.db.rdf.vocabulary
-------------------------------------------------------------------------------------------
RDF::Vocabulary::Generator		edu.stanford.db.rdf.vocabulary.Generator

RDF::Vocabulary::RDF			org.w3c.rdf.vocabulary.rdf_syntax_19990222.RDF
RDF::Vocabulary::RDFS			org.w3c.rdf.vocabulary.rdf_schema_19990303.RDFS
RDF::Vocabulary::DC				org.w3c.rdf.vocabulary.dublin_core_19990702.DC


The Perl RDF API implementation is almost aligned with the Java one (some feauture were left out because for it difficulty or impossibility in the implementation). E.g. Perl do not have Exceptions as built in construcut, and altough they could be easily implemented with eval() and $@ checking, RDFStore just uses the Carp module to warn, croak or confess on errors. In the RDF::Store branch the modules code has been extended and modified to use the Data::MagicTie(3) interface and a different indexing mechanism in RDF::Store::FindIndex(3). Similarly the RDF::Vocabulary::Generator(3) now generates valid Perl5 modules containing constants definitions of input RDF Schema.

For the whole API documentation you can temporarly refer to the JavaDoc version at http://www-db.stanford.edu/~melnik/rdf/api-doc/

In addition I invite you to look at the samples and utils directory coming with the RDFStore distribution for a fruitful set of examples to play with :-)

=head1 BUGS

This module implements most of the classes and packages as its Java counterpart from the Stanford University Database Group by Sergey Melnik (see http://www-db.stanford.edu/~melnik/rdf/api.html), but some feature have been missied on purposed or just forgotten ;-)

=head1 SEE ALSO

XML::Parser::PenRDF(3), DBMS(3) and XML::Parser(3) XML::Parser::Expat(3)
RDF::Model(3) RDF::Store::NodeFactory(3)
	Summary of Recent Discussions about an Application Programming Interface for RDF - http://nestroy.wi-inf.uni-essen.de/rdf/sum_rdf_api/

	RDF Model and Syntax Specification - http://www.w3.org/TR/REC-rdf-syntax
	RDF Schema Specification 1.0 - http://www.w3.org/TR/2000/CR-rdf-schema-20000327
=head1 AUTHOR

	Alberto Reggiori <alberto.reggiori@jrc.it>

	Sergey Melnik <melnik@db.stanford.edu> is the original author of the Java RDF API - txs Sergey!
