# *
# *	Copyright (c) 2000 Alberto Reggiori / <alberto.reggiori@jrc.it>
# *	ISIS/RIT, Joint Research Center Ispra (I)
# *
# * NOTICE
# *
# * This product is distributed under a BSD/ASF like license as described in the 'LICENSE'
# * file you should have received together with this source code. If you did not get a
# * a copy of such a license agreement you can pick up one at:
# *
# *     http://xml.jrc.it/RDFStore/LICENSE
# *
# *
package RDF::Store::NodeFactory;
{
use Carp;
use RDF::NodeFactory;
use RDF::Store::Literal;
use RDF::Store::Resource;
use RDF::Store::Statement;
use RDF::Digest::Util;

@RDF::Store::NodeFactory::ISA = qw ( RDF::NodeFactory );

sub new {
    	bless $_[0]->SUPER::new(@_),shift;
};

sub createResource {
	return (defined $_[1]) ? new RDF::Store::Resource($_[1]) : undef;
};

sub createLiteral {
	return (defined $_[1]) ? new RDF::Store::Literal($_[1]) : undef;
};

sub createStatement {
	return ( 	(defined $_[1]) && 
			(defined $_[2]) && 
			(defined $_[3]) ) ? new RDF::Store::Statement($_[1],$_[2],$_[3]) :
			undef;
};

# Creates a resource with a unique ID
sub createUniqueResource {
	return new RDF::Store::Resource("urn:rdf:" .
				RDF::Digest::Util::computeDigest("SHA-1",rand)->toString);
};

# Creates an ordinal property (rdf:li, rdf:_N)
# to me does not make send hereish - by AR
sub createOrdinal {
	croak "Why do you want to create Ordinals here?\nCould'nt your application be aware of RDF spec and pass the right URI to createResource() instead? :-)";
};

1;
};

__END__

=head1 NAME

RDF::Store::NodeFactory - implementation of the NodeFactory RDF API

=head1 SYNOPSIS

	use RDF::Store::NodeFactory;
	my $factory = new RDF::Store::NodeFactory();
	my $statement = $factory->createStatement(
				$factory->createResource("http://pen.jrc.it"),
  				$factory->createResource("http://purl.org/schema/1.0#author"),
  				$factory->createLiteral("Alberto Reggiori")
				);


=head1 DESCRIPTION

An RDF::NodeFactory implementation using RDF::Store::RDFNode, RDF::Store::Resource and RDF::Store::Literal

=head1 SEE ALSO

RDF::Store::RDFNode(3) RDF::Store::Resource(3) RDF::Store::Literal(3)

=head1 AUTHOR

	Alberto Reggiori <alberto.reggiori@jrc.it>
